<?php
/*-----------------------------------------------------------------------------------

CLASS INFORMATION

Description: A custom WooThemes 125x125 Ads widget.
Date Created: 2011-07-11.
Last Modified: 2011-07-11.
Author: WooThemes.
Since: 2.9.0


TABLE OF CONTENTS

- var $woo_widget_cssclass
- var $woo_widget_description
- var $woo_widget_idbase
- var $woo_widget_title

- function (constructor)
- function widget ()
- function update ()
- function form ()

- Register the widget on `widgets_init`.

-----------------------------------------------------------------------------------*/

class Woo_Widget_Ads_125 extends WP_Widget {

	/*----------------------------------------
	  Variable Declarations.
	  ----------------------------------------
	  
	  * Variables to setup the widget.
	----------------------------------------*/

	var $woo_widget_cssclass;
	var $woo_widget_description;
	var $woo_widget_idbase;
	var $woo_widget_title;

	/*----------------------------------------
	  Constructor.
	  ----------------------------------------
	  
	  * The constructor. Sets up the widget.
	----------------------------------------*/
	
	function Woo_Widget_Ads_125 () {
	
		/* Widget variable settings. */
		$this->woo_widget_cssclass = 'widget_woo_ads_125';
		$this->woo_widget_description = __( 'This is a WooThemes standardized 125x125 Adspace widget.', 'woothemes' );
		$this->woo_widget_idbase = 'advert_125x125';
		$this->woo_widget_title = __('Woo - Ads 125x125', 'woothemes' );
		
		/* Widget settings. */
		$widget_ops = array( 'classname' => $this->woo_widget_cssclass, 'description' => $this->woo_widget_description );

		/* Widget control settings. */
		$control_ops = array( 'width' => 250, 'height' => 350, 'id_base' => $this->woo_widget_idbase );

		/* Create the widget. */
		$this->WP_Widget( $this->woo_widget_idbase, $this->woo_widget_title, $widget_ops, $control_ops );
		
	} // End Constructor

	/*----------------------------------------
	  widget()
	  ----------------------------------------
	  
	  * Displays the widget on the frontend.
	----------------------------------------*/

	function widget( $args, $instance ) {  
		
		$html = '';
		
		extract( $args, EXTR_SKIP );
		
		/* Our variables from the widget settings. */
		$number = $instance['ads_number'];
		
		if ( $number == 0 ) { $number = 1; }
		$img_url = array();
		$dest_url = array();
		
		$numbers = range( 1, $number ); 
		$counter = 0;
		
		if ( get_option( 'woo_ads_rotate' ) == 'true' ) {
			shuffle( $numbers );
		}

		$before_widget = str_replace( 'class="widget', 'class="widget wrap', $before_widget );
		
		/* Before widget (defined by themes). */
		echo $before_widget;
		
		/* Widget content. */
		
		// Add actions for plugins/themes to hook onto.
		do_action( $this->woo_widget_cssclass . '_top' );
		
		// Load widget content here.
		$html = '';
		
		foreach ($numbers as $number) {	
			$counter++;
			$img_url[$counter] = get_option( 'woo_ad_image_' . $number );
			$dest_url[$counter] = get_option( 'woo_ad_url_' . $number );
		
			$html .= '<a href="' . $dest_url[$counter] . '"><img src="' . $img_url[$counter] . '" alt="Ad" /></a>' . "\n";
		}
		
		echo $html; // If using the $html variable to store the output, you need this. ;)
		
		// Add actions for plugins/themes to hook onto.
		do_action( $this->woo_widget_cssclass . '_bottom' );

		/* After widget (defined by themes). */
		echo $after_widget;

	} // End widget()

	/*----------------------------------------
	  update()
	  ----------------------------------------
	
	* Function to update the settings from
	* the form() function.
	
	* Params:
	* - Array $new_instance
	* - Array $old_instance
	----------------------------------------*/
	
	function update ( $new_instance, $old_instance ) {
		
		$instance = $old_instance;
		
		/* The select box is returning a text value, so we escape it. */
		$instance['ads_number'] = esc_attr( $new_instance['ads_number'] );
		return $instance;
		
	} // End update()

   /*----------------------------------------
	 form()
	 ----------------------------------------
	  
	  * The form on the widget control in the
	  * widget administration area.
	  
	  * Make use of the get_field_id() and 
	  * get_field_name() function when creating
	  * your form elements. This handles the confusing stuff.
	  
	  * Params:
	  * - Array $instance
	----------------------------------------*/

   function form( $instance ) {       
   
		/* Set up some default widget settings. */
		$defaults = array(
						'ads_number' => 1
					);
		
		$instance = wp_parse_args( (array) $instance, $defaults );
?>
		<!-- Widget Ads Number: Select Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'ads_number' ); ?>"><?php _e( 'Number of Ads (1-4):', 'woothemes' ); ?></label>
			<select name="<?php echo $this->get_field_name( 'ads_number' ); ?>" class="widefat" id="<?php echo $this->get_field_id( 'ads_number' ); ?>">
				<?php for ( $i = 1; $i <= 4; $i++ ) { ?>
				<option value="<?php echo $i; ?>"<?php selected( $instance['ads_number'], $i ); ?>><?php echo $i; ?></option>
			<?php } ?>        
			</select>
		</p><?php
	} // End form()
	
} // End Class

/*----------------------------------------
  Register the widget on `widgets_init`.
  ----------------------------------------
  
  * Registers this widget.
----------------------------------------*/

add_action( 'widgets_init', create_function( '', 'return register_widget("Woo_Widget_Ads_125");' ), 1 ); 
?>