<?php
/*-----------------------------------------------------------------------------------

CLASS INFORMATION

Description: A custom WooThemes comments widget.
Date Created: 2011-05-10.
Last Modified: 2011-05-10.
Author: WooThemes.
Since: 1.0.0


TABLE OF CONTENTS

- var $woo_widget_cssclass
- var $woo_widget_description
- var $woo_widget_idbase
- var $woo_widget_title

- function (constructor)
- function widget ()
- function update ()
- function form ()

- Register the widget on `widgets_init`.

-----------------------------------------------------------------------------------*/

class Woo_Widget_Comments extends WP_Widget {

	/*----------------------------------------
	  Variable Declarations.
	  ----------------------------------------
	  
	  * Variables to setup the widget.
	----------------------------------------*/

	var $woo_widget_cssclass;
	var $woo_widget_description;
	var $woo_widget_idbase;
	var $woo_widget_title;

	/*----------------------------------------
	  Constructor.
	  ----------------------------------------
	  
	  * The constructor. Sets up the widget.
	----------------------------------------*/
	
	function Woo_Widget_Comments () {
	
		/* Widget variable settings. */
		$this->woo_widget_cssclass = 'widget_woo_comments';
		$this->woo_widget_description = __( 'This is a WooThemes standardized comments widget.', 'woothemes' );
		$this->woo_widget_idbase = 'woo_comments';
		$this->woo_widget_title = __('Woo - Recent Comments', 'woothemes' );
		
		/* Widget settings. */
		$widget_ops = array( 'classname' => $this->woo_widget_cssclass, 'description' => $this->woo_widget_description );

		/* Widget control settings. */
		$control_ops = array( 'width' => 250, 'height' => 350, 'id_base' => $this->woo_widget_idbase );

		/* Create the widget. */
		$this->WP_Widget( $this->woo_widget_idbase, $this->woo_widget_title, $widget_ops, $control_ops );
		
	} // End Constructor

	/*----------------------------------------
	  widget()
	  ----------------------------------------
	  
	  * Displays the widget on the frontend.
	----------------------------------------*/

	function widget( $args, $instance ) {  
		
		$html = '';
		
		extract( $args, EXTR_SKIP );
		
		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'], $instance, $this->id_base );
		$number = $instance['number'];
		$desc = $instance['desc'];
			
		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title ) {
		
			echo $before_title . $title;
?>
			<a href="<?php bloginfo( 'comments_rss2_url' ); ?>" title="<?php _e( 'Subscribe to Recent Comments', 'woothemes' ); ?>"><img src="<?php echo get_template_directory_uri(); ?>/images/ico-rss.png" alt="<?php _e( 'Subscribe to Recent Comments', 'woothemes' ); ?>" /></a>
<?php
			echo $after_title;
		
		} // End IF Statement
		
		if ( $desc != '' ) { ?><span class="description"><?php echo $desc; ?></span><?php }
		
		/* Widget content. */
		
		// Add actions for plugins/themes to hook onto.
		do_action( $this->woo_widget_cssclass . '_top' );
		
		// Load widget content here.
		$comments = get_comments( array( 'number' => $number, 'status' => 'approve' ) );
		
		if ( $comments ) {
			foreach ( (array) $comments as $comment) {
			$post = get_post( $comment->comment_post_ID );
		?>
				<div class="item">		
			
					<div class="excerpt">
						<p><?php echo substr( strip_tags( $comment->comment_content ), 0, 50 ); ?>…</p>
					</div><!-- /.excerpt -->
			
					<div class="comment-author">			
						<p><?php echo strip_tags( $comment->comment_author ); ?> <?php _e( 'on', 'woothemes' ); ?> <a href="<?php echo get_permalink( $post->ID ); ?>#comment-<?php echo $comment->comment_ID; ?>" title="<?php echo esc_attr( $post->post_title ); ?>"><?php echo $post->post_title; ?></a></p>			
					</div><!-- /.comment-author -->
		
				</div><!-- /.item -->
		<?php	
			} // End FOREACH Loop
			
 		} // End IF Statement
		
		// Add actions for plugins/themes to hook onto.
		do_action( $this->woo_widget_cssclass . '_bottom' );

		/* After widget (defined by themes). */
		echo $after_widget;

	} // End widget()

	/*----------------------------------------
	  update()
	  ----------------------------------------
	
	* Function to update the settings from
	* the form() function.
	
	* Params:
	* - Array $new_instance
	* - Array $old_instance
	----------------------------------------*/
	
	function update ( $new_instance, $old_instance ) {
		
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['number'] = esc_attr( $new_instance['number'] );
		
		/* The textarea is returning a text value, so we escape it. */
		$instance['desc'] = esc_html( $new_instance['desc'] );
		
		return $instance;
		
	} // End update()

   /*----------------------------------------
	 form()
	 ----------------------------------------
	  
	  * The form on the widget control in the
	  * widget administration area.
	  
	  * Make use of the get_field_id() and 
	  * get_field_name() function when creating
	  * your form elements. This handles the confusing stuff.
	  
	  * Params:
	  * - Array $instance
	----------------------------------------*/

   function form( $instance ) {       
   
		/* Set up some default widget settings. */
		$defaults = array(
						'title' => __( 'Recent Comments', 'woothemes' ), 
						'number' => 5, 
						'desc' => ''
					);
		
		$instance = wp_parse_args( (array) $instance, $defaults );
?>
		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title (optional):', 'woothemes' ); ?></label>
			<input type="text" name="<?php echo $this->get_field_name( 'title' ); ?>"  value="<?php echo $instance['title']; ?>" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" />
		</p>
		<!-- Widget Number: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of comments:', 'woothemes' ); ?></label>
			<input type="text" name="<?php echo $this->get_field_name( 'number' ); ?>"  value="<?php echo $instance['number']; ?>" class="widefat" id="<?php echo $this->get_field_id( 'number' ); ?>" />
		</p>
		<!-- Widget Example Textarea: Textarea -->
		<p>
			<label for="<?php echo $this->get_field_id( 'desc' ); ?>"><?php _e( 'Description:', 'woothemes' ); ?></label>
			<textarea name="<?php echo $this->get_field_name( 'desc' ); ?>" class="widefat" rows="5" id="<?php echo $this->get_field_id( 'desc' ); ?>"><?php echo $instance['desc']; ?></textarea>
		</p>
<?php
	} // End form()
	
} // End Class

/*----------------------------------------
  Register the widget on `widgets_init`.
  ----------------------------------------
  
  * Registers this widget.
----------------------------------------*/

add_action( 'widgets_init', create_function( '', 'return register_widget("Woo_Widget_Comments");' ), 1 ); 
?>