<?php
/*-----------------------------------------------------------------------------------

CLASS INFORMATION

Description: A custom WooThemes Feedburner widget.
Date Created: 2011-07-25.
Last Modified: 2011-07-25.
Author: WooThemes.
Since: 1.4.0


TABLE OF CONTENTS

- var $woo_widget_cssclass
- var $woo_widget_description
- var $woo_widget_idbase
- var $woo_widget_title

- function (constructor)
- function widget ()
- function update ()
- function form ()

- Register the widget on `widgets_init`.

-----------------------------------------------------------------------------------*/

class Woo_Widget_Feedburner extends WP_Widget {

	/*----------------------------------------
	  Variable Declarations.
	  ----------------------------------------
	  
	  * Variables to setup the widget.
	----------------------------------------*/

	var $woo_widget_cssclass;
	var $woo_widget_description;
	var $woo_widget_idbase;
	var $woo_widget_title;

	/*----------------------------------------
	  Constructor.
	  ----------------------------------------
	  
	  * The constructor. Sets up the widget.
	----------------------------------------*/
	
	function Woo_Widget_Feedburner () {
	
		/* Widget variable settings. */
		$this->woo_widget_cssclass = 'widget_woo_feedburner';
		$this->woo_widget_description = __( 'This is a WooThemes standardized Feedburner widget.', 'woothemes' );
		$this->woo_widget_idbase = 'woo_feedburner';
		$this->woo_widget_title = __('Woo - Feedburner', 'woothemes' );
		
		/* Widget settings. */
		$widget_ops = array( 'classname' => $this->woo_widget_cssclass, 'description' => $this->woo_widget_description );

		/* Widget control settings. */
		$control_ops = array( 'width' => 250, 'height' => 350, 'id_base' => $this->woo_widget_idbase );

		/* Create the widget. */
		$this->WP_Widget( $this->woo_widget_idbase, $this->woo_widget_title, $widget_ops, $control_ops );
		
	} // End Constructor

	/*----------------------------------------
	  widget()
	  ----------------------------------------
	  
	  * Displays the widget on the frontend.
	----------------------------------------*/

	function widget( $args, $instance ) {  
		
		$html = '';
		
		extract( $args, EXTR_SKIP );
		
		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'], $instance, $this->id_base );
		
		$feedburner_id = $instance['feedburner_id'];
		$subscribe_google = $instance['subscribe_google'];
		
		if ( $feedburner_id == '' ) { return; }
		
		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title ) {
		
			echo $before_title . $title . $after_title;
		
		} // End IF Statement
		
		/* Widget content. */
		
		// Add actions for plugins/themes to hook onto.
		do_action( $this->woo_widget_cssclass . '_top' );
		
		// Load widget content here.
?>
		<form action="<?php if ( $subscribe_google ) { ?>http://feedburner.google.com/fb/a/mailverify<?php } else { ?>http://www.feedburner.com/fb/a/emailverify<?php } ?>" method="post" target="popupwindow" onsubmit="window.open('<?php if ( $subscribe_google ) { ?>http://feedburner.google.com/fb/a/mailverify?uri=<?php } else { ?>http://www.feedburner.com/fb/a/emailverifySubmit?feedId=<?php } ?><?php echo $feedburner_id; ?>', 'popupwindow', 'scrollbars=yes,width=550,height=520');return true">
		
		<input class="field" type="text" name="email" value="<?php _e( 'Enter your e-mail address', 'woothemes' ); ?>" onfocus="if (this.value == '<?php _e( 'Enter your e-mail address', 'woothemes' ); ?>') {this.value = '';}" onblur="if (this.value == '') {this.value = '<?php _e( 'Enter your e-mail address', 'woothemes' ); ?>';}" />
		<input type="hidden" value="<?php echo $feedburner_id; ?>" name="uri"/>
		<input type="hidden" value="<?php bloginfo( 'name' ); ?>" name="title" />
		<input type="hidden" name="loc" value="en_US"/>
		
		<input class="button" type="submit" name="submit" value="<?php _e( 'submit', 'woothemes' ); ?>" />
		
		</form>
<?php	
		// Add actions for plugins/themes to hook onto.
		do_action( $this->woo_widget_cssclass . '_bottom' );

		/* After widget (defined by themes). */
		echo $after_widget;

	} // End widget()

	/*----------------------------------------
	  update()
	  ----------------------------------------
	
	* Function to update the settings from
	* the form() function.
	
	* Params:
	* - Array $new_instance
	* - Array $old_instance
	----------------------------------------*/
	
	function update ( $new_instance, $old_instance ) {
		
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['feedburner_id'] = strip_tags( $new_instance['feedburner_id'] );
		
		/* The checkbox is returning a Boolean (true/false), so we check for that. */
		$instance['subscribe_google'] = (bool) esc_attr( $new_instance['subscribe_google'] );
		
		return $instance;
		
	} // End update()

   /*----------------------------------------
	 form()
	 ----------------------------------------
	  
	  * The form on the widget control in the
	  * widget administration area.
	  
	  * Make use of the get_field_id() and 
	  * get_field_name() function when creating
	  * your form elements. This handles the confusing stuff.
	  
	  * Params:
	  * - Array $instance
	----------------------------------------*/

   function form( $instance ) {       
   
		/* Set up some default widget settings. */
		$defaults = array(
						'title' => __( 'Feedburner', 'woothemes' ), 
						'feedburner_id' => '', 
						'subscribe_google' => 1
					);
		
		$instance = wp_parse_args( (array) $instance, $defaults );
?>
		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title (optional):', 'woothemes' ); ?></label>
			<input type="text" name="<?php echo $this->get_field_name( 'title' ); ?>"  value="<?php echo $instance['title']; ?>" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" />
		</p>
		<!-- Widget Feedburner ID: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'feedburner_id' ); ?>"><?php _e( 'Your Feedburner ID:', 'woothemes' ); ?></label>
			<input type="text" name="<?php echo $this->get_field_name( 'feedburner_id' ); ?>"  value="<?php echo $instance['feedburner_id']; ?>" class="widefat" id="<?php echo $this->get_field_id( 'feedburner_id' ); ?>" />
		</p>
		<!-- Widget Use Google URL: Checkbox Input -->
       	<p>
        	<input id="<?php echo $this->get_field_id( 'subscribe_google' ); ?>" name="<?php echo $this->get_field_name( 'subscribe_google' ); ?>" type="checkbox"<?php checked( $instance['subscribe_google'], 1 ); ?> value="1" />
        	<label for="<?php echo $this->get_field_id( 'subscribe_google' ); ?>"><?php _e( 'Use Feedburner Google URL?', 'woothemes' ); ?></label>
	   	</p>
<?php
	} // End form()
	
} // End Class

/*----------------------------------------
  Register the widget on `widgets_init`.
  ----------------------------------------
  
  * Registers this widget.
----------------------------------------*/

add_action( 'widgets_init', create_function( '', 'return register_widget("Woo_Widget_Feedburner");' ), 1 ); 
?>