<?php
/*-----------------------------------------------------------------------------------

CLASS INFORMATION

Description: A custom WooThemes News widget.
Date Created: 2011-07-25.
Last Modified: 2011-07-25.
Author: WooThemes.
Since: 1.5.0


TABLE OF CONTENTS

- var $woo_widget_cssclass
- var $woo_widget_description
- var $woo_widget_idbase
- var $woo_widget_title

- function (constructor)
- function widget ()
- function update ()
- function form ()

- Register the widget on `widgets_init`.

-----------------------------------------------------------------------------------*/

class Woo_Widget_News extends WP_Widget {

	/*----------------------------------------
	  Variable Declarations.
	  ----------------------------------------
	  
	  * Variables to setup the widget.
	----------------------------------------*/

	var $woo_widget_cssclass;
	var $woo_widget_description;
	var $woo_widget_idbase;
	var $woo_widget_title;

	/*----------------------------------------
	  Constructor.
	  ----------------------------------------
	  
	  * The constructor. Sets up the widget.
	----------------------------------------*/
	
	function Woo_Widget_News () {
	
		/* Widget variable settings. */
		$this->woo_widget_cssclass = 'widget_woo_news';
		$this->woo_widget_description = __( 'This is a WooThemes standardized news widget.', 'woothemes' );
		$this->woo_widget_idbase = 'woo_news';
		$this->woo_widget_title = __('Woo - News from the blog', 'woothemes' );
		
		/* Widget settings. */
		$widget_ops = array( 'classname' => $this->woo_widget_cssclass, 'description' => $this->woo_widget_description );

		/* Widget control settings. */
		$control_ops = array( 'width' => 250, 'height' => 350, 'id_base' => $this->woo_widget_idbase );

		/* Create the widget. */
		$this->WP_Widget( $this->woo_widget_idbase, $this->woo_widget_title, $widget_ops, $control_ops );
		
	} // End Constructor

	/*----------------------------------------
	  widget()
	  ----------------------------------------
	  
	  * Displays the widget on the frontend.
	----------------------------------------*/

	function widget( $args, $instance ) {  
		
		$html = '';
		
		extract( $args, EXTR_SKIP );
		
		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'], $instance, $this->id_base );
		$desc = $instance['desc'];
		$number = $instance['number'];
		$cat = $instance['cat'];
		
		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title ) {
		
			echo $before_title . $title;
?>
	<a href="<?php if ( get_option('woo_feedburner_url') <> "" ) { echo get_option('woo_feedburner_url'); } else { echo get_bloginfo_rss('rss2_url'); } ?>" title="<?php _e( 'Subscribe to RSS', 'woothemes' ); ?>"><img src="<?php echo get_template_directory_uri(); ?>/images/ico-rss.png" alt="<?php _e( 'Subscribe to RSS', 'woothemes' ); ?>" /></a>
<?php
			echo $after_title;
			
			if ( $desc != '' ) { ?><span class="description"><?php echo $desc; ?></span><?php }
		
		} // End IF Statement
		
		/* Widget content. */
					 	
	 	$posts = get_posts('numberposts=' . $number . '&category=' . $category);
		 foreach($posts as $post) :
   		setup_postdata($post);
?>

	<div class="item">

		<div class="date">
			<span class="month"><?php echo get_the_time( 'M', $post->ID ); ?></span> <span class="day"><?php echo get_the_time( 'd', $post->ID ); ?></span>
		</div><!-- /.date -->

		<div class="excerpt">
			<h4><a href="<?php echo get_permalink( $post->ID ); ?>" title="<?php echo esc_attr( get_the_title( $post->ID ) ); ?>"><?php echo get_the_title( $post->ID ); ?></a></h4>

			<p><?php echo $post->post_excerpt; ?></p>
		<a href="<?php echo get_permalink( $post->ID ); ?>" title="<?php echo esc_attr( get_the_title( $post->ID ) ); ?>"><?php _e( 'Read the rest', 'woothemes' ); ?> &raquo;</a>
		</div><!-- /.excerpt -->

	</div><!-- /.item -->	
	    
	<?php endforeach; ?>

<div class="clear"></div>

<?php
		// Add actions for plugins/themes to hook onto.
		do_action( $this->woo_widget_cssclass . '_top' );
		
		// Load widget content here.
		
		// Add actions for plugins/themes to hook onto.
		do_action( $this->woo_widget_cssclass . '_bottom' );

		/* After widget (defined by themes). */
		echo $after_widget;

	} // End widget()

	/*----------------------------------------
	  update()
	  ----------------------------------------
	
	* Function to update the settings from
	* the form() function.
	
	* Params:
	* - Array $new_instance
	* - Array $old_instance
	----------------------------------------*/
	
	function update ( $new_instance, $old_instance ) {
		
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		
		$instance['number'] = strip_tags( $new_instance['number'] );
		
		/* The select box is returning a text value, so we escape it. */
		$instance['cat'] = esc_attr( $new_instance['cat'] );
		
		/* The textarea is returning a text value, so we escape it. */
		$instance['desc'] = esc_html( $new_instance['desc'] );
		
		return $instance;
		
	} // End update()

   /*----------------------------------------
	 form()
	 ----------------------------------------
	  
	  * The form on the widget control in the
	  * widget administration area.
	  
	  * Make use of the get_field_id() and 
	  * get_field_name() function when creating
	  * your form elements. This handles the confusing stuff.
	  
	  * Params:
	  * - Array $instance
	----------------------------------------*/

   function form( $instance ) {       
   
		/* Set up some default widget settings. */
		$defaults = array(
						'title' => __( 'News from the blog', 'woothemes' ), 
						'cat' => '', 
						'number' => 5, 
						'desc' => ''
					);
		
		$instance = wp_parse_args( (array) $instance, $defaults );
?>
		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title (optional):', 'woothemes' ); ?></label>
			<input type="text" name="<?php echo $this->get_field_name( 'title' ); ?>"  value="<?php echo $instance['title']; ?>" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" />
		</p>
		<!-- Widget Number: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of posts:', 'woothemes' ); ?></label>
			<input type="text" name="<?php echo $this->get_field_name( 'number' ); ?>"  value="<?php echo $instance['number']; ?>" class="widefat" id="<?php echo $this->get_field_id( 'number' ); ?>" />
		</p>
		<!-- Widget Example Select: Select Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'cat' ); ?>"><?php _e( 'Category:', 'woothemes' ); ?></label>
			<?php
				$args = array( 'name' => $this->get_field_name( 'cat' ), 'id' => $this->get_field_id( 'cat' ), 'selected' => $instance['cat'] );
				wp_dropdown_categories( $args );
			?>
		</p>
		<!-- Widget Example Textarea: Textarea -->
		<p>
			<label for="<?php echo $this->get_field_id( 'desc' ); ?>"><?php _e( 'Description:', 'woothemes' ); ?></label>
			<textarea name="<?php echo $this->get_field_name( 'desc' ); ?>" class="widefat" rows="5" id="<?php echo $this->get_field_id( 'desc' ); ?>"><?php echo $instance['desc']; ?></textarea>
		</p>
<?php
	} // End form()
	
} // End Class

/*----------------------------------------
  Register the widget on `widgets_init`.
  ----------------------------------------
  
  * Registers this widget.
----------------------------------------*/

add_action( 'widgets_init', create_function( '', 'return register_widget("Woo_Widget_News");' ), 1 ); 
?>