<?php
/*-----------------------------------------------------------------------------------

CLASS INFORMATION

Description: A custom WooThemes video widget.
Date Created: 2011-07-25.
Last Modified: 2011-07-25.
Author: WooThemes.
Since: 1.5.0


TABLE OF CONTENTS

- var $woo_widget_cssclass
- var $woo_widget_description
- var $woo_widget_idbase
- var $woo_widget_title

- function (constructor)
- function widget ()
- function update ()
- function form ()

- Register the widget on `widgets_init`.

-----------------------------------------------------------------------------------*/

class Woo_Widget_Video extends WP_Widget {
	
	function Woo_Widget_Video () {
	
		/* Widget settings. */
		$widget_ops = array( 'classname' => 'widget_woo_video', 'description' => __( 'This is the WooThemes Video Embed widget.', 'woothemes' ) );

		/* Widget control settings. */
		$control_ops = array( 'width' => 250, 'height' => 350, 'id_base' => 'woo_widget_video' );

		/* Create the widget. */
		$this->WP_Widget( 'woo_widget_video', __('Woo - Video', 'woothemes' ), $widget_ops, $control_ops );
	
	} // End Constructor
	
	function widget ( $args, $instance ) {
	
		extract( $args, EXTR_SKIP );
		
		$title = apply_filters( 'widget_title', $instance['title'] );
		$number = $instance['video_number'];
		
?>
	<div id="videos" class="box widget">
	
			<h3><?php if ( $title != '' ) { echo $title; } else { _e( 'Video Player', 'woothemes' ); } ?></h3>
			
			<div class="inner">

				<?php
					global $post;
					$videos = new WP_Query( 'posts_per_page=' . $number . '&tag=video' );
					
					if ( $videos->have_posts() ) {
					
					$count = 0;
					
					while( $videos->have_posts() ) { $videos->the_post(); $count++;
					
					if ( $count == 1 ) {
		 		?>					
			
				<h4><a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_title(); ?></a></h4>
				
				<div class="video">
					<?php echo woo_get_embed('embed','259','186'); ?> 
				</div><!-- /.video -->
				<h4><?php _e( 'More', 'woothemes' ); ?>…</h4>
				<ul>
				<?php
					} else {
				?>
					<li><a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_title(); ?></a></li>
				<?php
					}
				}
				?>
				<?php } ?>
				</ul>
			
			</div><!-- /.inner -->
	
	</div><!-- /#videos -->
<?php
	
	} // End widget()
	
	function update ( $new_instance, $old_instance ) {
	
		$instance = $old_instance;

		$new_instance['video_number'] = intval( $new_instance['video_number'] );
		
		if ( $new_instance['video_number'] == 0 ) { $new_instance['video_number'] = 5; }

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['video_number'] = esc_attr( $new_instance['video_number'] );

		return $instance;
	
	} // End update()
	
	function form ( $instance ) {
	
		/* Set up some default widget settings. */
		$defaults = array(
						'title' => __( 'Latest Videos', 'woothemes' ), 
						'video_number' => 5
					);

		$instance = wp_parse_args( (array) $instance, $defaults );
?>
		<!-- Widget Title: Text Input -->
		<p>
		   <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'woothemes' ); ?></label>
		   <input type="text" name="<?php echo $this->get_field_name( 'title' ); ?>"  value="<?php echo $instance['title']; ?>" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" />
		</p>
		<!-- Widget Video Number: Text Input -->
		<p>
		   <label for="<?php echo $this->get_field_id( 'video_number' ); ?>"><?php _e( 'Number of Videos:', 'woothemes' ); ?></label>
		   <input type="text" name="<?php echo $this->get_field_name( 'video_number' ); ?>"  value="<?php echo $instance['video_number']; ?>" class="widefat" id="<?php echo $this->get_field_id( 'video_number' ); ?>" />
		</p>
<?php
	} // End form()
	
} // End Class

/*----------------------------------------
  Register the widget on `widgets_init`.
  ----------------------------------------
  
  * Registers this widget.
----------------------------------------*/

add_action( 'widgets_init', create_function( '', 'return register_widget("Woo_Widget_Video");' ), 1 ); 
?>